aiotaskpool
====================
[![Travis CI Status](https://travis-ci.org/zeroguard/aiotaskpool.svg?branch=master)](https://travis-ci.org/zeroguard/aiotaskpool)
[![Coverage Status](https://coveralls.io/repos/github/zeroguard/aiotaskpool/badge.svg?branch=master)](https://coveralls.io/github/zeroguard/aiotaskpool?branch=master)
![PyPI Status](https://img.shields.io/pypi/status/aiotaskpool)
![PyPI Version](https://img.shields.io/pypi/v/aiotaskpool)
![Repository License](https://img.shields.io/github/license/zeroguard/aiotaskpool)
![PyPI Python Version](https://img.shields.io/pypi/pyversions/aiotaskpool)
